using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.IO;

namespace JDP {
	public partial class frmMain : Form {
		private Thread _workThread;

		public frmMain() {
			InitializeComponent();
		}

		private void ExtractFilesThread(object p) {
			string[] files = (string[])p;

			Invoke((MethodInvoker)delegate() {
				Enabled = false;
			});

			for (int i = 0; i < files.Length; i++) {
				ExtractFile(files[i]);
			}

			Invoke((MethodInvoker)delegate() {
				Enabled = true;
			});
		}

		private void ExtractFile(string path) {
			string mbStart = Path.GetFileName(path) + Environment.NewLine + Environment.NewLine;

			try {
				FLVFile flvFile = new FLVFile(path);
				flvFile.ExtractStreams(chkAudio.Checked, chkVideo.Checked, chkTimeCodes.Checked);
				flvFile.Close();

				Invoke((MethodInvoker)delegate() {
					MessageBox.Show(this, String.Format("{0}Finished!{1}Average Frame Rate: {2}{1}" +
						"Estimated True Frame Rate: {3}", mbStart, Environment.NewLine,
						flvFile.AverageFrameRate, flvFile.TrueFrameRate), "Done",
						MessageBoxButtons.OK, MessageBoxIcon.Information);
				});
			}
			catch (Exception ex) {
				Invoke((MethodInvoker)delegate() {
					MessageBox.Show(this, mbStart + ex.Message, "Error", MessageBoxButtons.OK,
						MessageBoxIcon.Error);
				});
			}
		}

		private void LoadSettings() {
			SettingsReader sr = new SettingsReader("FLV Extract", "settings.txt");
			string val;

			if ((val = sr.Load("ExtractVideo")) != null) {
				chkVideo.Checked = (val != "0");
			}
			if ((val = sr.Load("ExtractTimeCodes")) != null) {
				chkTimeCodes.Checked = (val != "0");
			}
			if ((val = sr.Load("ExtractAudio")) != null) {
				chkAudio.Checked = (val != "0");
			}
		}

		private void SaveSettings() {
			SettingsWriter sw = new SettingsWriter("FLV Extract", "settings.txt");

			sw.Save("ExtractVideo", chkVideo.Checked ? "1" : "0");
			sw.Save("ExtractTimeCodes", chkTimeCodes.Checked ? "1" : "0");
			sw.Save("ExtractAudio", chkAudio.Checked ? "1" : "0");

			sw.Close();
		}

		private void btnAbout_Click(object sender, EventArgs e) {
			MessageBox.Show(String.Format("FLV Extract v1.2.0{0}Copyright 2006 Moitah{0}" +
				"http://www.moitah.net/", Environment.NewLine), "About", MessageBoxButtons.OK,
				MessageBoxIcon.Information);
		}

		private void frmMain_DragEnter(object sender, DragEventArgs e) {
			if ((_workThread != null) && _workThread.IsAlive) return;

			if (e.Data.GetDataPresent(DataFormats.FileDrop)) {
				e.Effect = DragDropEffects.Copy;
			}
		}

		private void frmMain_DragDrop(object sender, DragEventArgs e) {
			if ((_workThread != null) && _workThread.IsAlive) return;

			if (e.Data.GetDataPresent(DataFormats.FileDrop)) {
				_workThread = new Thread(new ParameterizedThreadStart(ExtractFilesThread));
				_workThread.Start(e.Data.GetData(DataFormats.FileDrop));
			}
		}

		private void frmMain_Load(object sender, EventArgs e) {
			LoadSettings();
		}

		private void frmMain_FormClosed(object sender, FormClosedEventArgs e) {
			SaveSettings();
		}
	}
}